@@ -392,8 +392,8 @@ NSIG_Sweep **nsig_read_sweep(FILE *fp, NSIG_Product_file *prod_file)
 {
   NSIG_Sweep **s;
   int i, j, n;
-  static NSIG_Ingest_data_header **idh = NULL;
-  static NSIG_Raw_prod_bhdr *bhdr = NULL;
+  NSIG_Ingest_data_header **idh = NULL;
+  NSIG_Raw_prod_bhdr *bhdr = NULL;
   NSIG_Ray *nsig_ray;
   int data_mask, iray, nrays[12], max_rays;
   int masks[5];
@@ -442,7 +442,7 @@ NSIG_Sweep **nsig_read_sweep(FILE *fp, NSIG_Product_file *prod_file)
    */
 
 #define Vprint
-/* #undef  Vprint */
+#undef  Vprint
   /* Determine if we need to byte-swap values. */
   (void)nsig_endianess(&prod_file->rec1);
   
@@ -511,10 +511,10 @@ NSIG_Sweep **nsig_read_sweep(FILE *fp, NSIG_Product_file *prod_file)
   /* This is a NEW sweep. */
   iray = 0;
 #ifdef Vprint
-  int isweep;
+  {int isweep;
   isweep = NSIG_I2(idh[0]->sweep_num);
   printf("Number of rays in sweep %d is %d\n", isweep, max_rays);
-  
+  }
 #endif
   /* Allocate memory for sweep. */
   s = (NSIG_Sweep **) calloc (nparams, sizeof(NSIG_Sweep*));
