@@ -355,8 +355,12 @@ void RSL_radar_to_uf_fp(Radar *r, FILE *fp)
         /* TODO: Code within "#ifdef LUHDR_VR_AZ" below should be removed
          * once testing of merge_split_cuts is completed.
          */
-/* 5/18/2010 Temporarily define LUHDR_VR_AZ until merge_split_cuts is
-   completed. */
+/* 7/25/2011 There's really no need to remove this code after merge_split_cuts.
+ * We can continue using it for exact VR azimuth in RSL.  Non-RSL programs can
+ * use the mandatory header azimuth, which is exact for DZ and a close
+ * approximation for VR when merge-split-cuts is applied.
+ */
+/* Preprocessor directives are for testing. */
 #define LUHDR_VR_AZ
 #ifdef LUHDR_VR_AZ
         /* If DZ and VR azimuths are different, store VR azimuth in Local Use
